//Source file: CallEndedReport.java
//Date: September 2004
//Generic Call Control Data Types for 3GPP TS 29.198-04-2 V5.8.0

package org.csapi.jr.se.cc.gccs;

/**
 * Defines the Sequence of Data Elements that specify the reason for the call ending.
 * 
 */
public final class CallEndedReport implements java.io.Serializable {

    private int callLegSessionID;
    private org.csapi.jr.se.cc.gccs.CallReleaseCause cause;

    /**
     * Creates a new CallEndedReport instance.
     */
    public CallEndedReport () {}

    /**
     * Creates a new CallEndedReport instance.
     * @param _callLegSessionID   The leg that initiated the release of the call.
If the call release was not initiated by the leg, then this value is set to -1.
     * @param _cause   The cause of the termination.
     */
    public CallEndedReport (int _callLegSessionID, org.csapi.jr.se.cc.gccs.CallReleaseCause _cause) {

        this.callLegSessionID = _callLegSessionID;
        this.cause = _cause;
    }

    /**
     * This method returns a callLegSessionID.
     * 
     * @return a int value
     */
    public int getCallLegSessionID() {
        return callLegSessionID;
    }

    /**
     * This method returns a cause.
     * 
     * @return a org.csapi.jr.se.cc.gccs.CallReleaseCause value
     */
    public org.csapi.jr.se.cc.gccs.CallReleaseCause getCause() {
        return cause;
    }


    /**
     * This method sets a callLegSessionID.
     */ 
    public void setCallLegSessionID(int callLegSessionID) {
        this.callLegSessionID = callLegSessionID;
    }

    /**
     * This method sets a cause.
     */ 
    public void setCause(org.csapi.jr.se.cc.gccs.CallReleaseCause cause) {
        this.cause = cause;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof CallEndedReport)) {
            return false;
        } 
        CallEndedReport callEndedReport = (CallEndedReport) o;
        if(!(this.callLegSessionID == callEndedReport.callLegSessionID)) {
            return false;
        }
        if ((this.cause != null) && (callEndedReport.cause != null)) {
            if(!(this.cause.equals(callEndedReport.cause))) {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // CallEndedReport

