//Source file: CallReleaseCause.java
//Date: September 2004
//Generic Call Control Data Types for 3GPP TS 29.198-04-2 V5.8.0

package org.csapi.jr.se.cc.gccs;

/**
 * Defines the Sequence of Data Elements that specify the cause of the release of a call. 
NOTE:	The Value and Location are specified as in ITU-T Recommendation Q.850.
The following example was taken from ITU-T Recommendation Q.850 to aid understanding:
Equivalent Call Report	Cause Value Set by Application	Cause Value from Network
P_CALL_REPORT_BUSY	17	17
P_CALL_REPORT_NO_ANSWER	19	18, 19, 21
P_CALL_REPORT_DISCONNECT	16	16
P_CALL_REPORT_REDIRECTED	23	23
P_CALL_REPORT_SERVICE_CODE	31	NA
P_CALL_REPORT_NOT_REACHABLE	20	20
P_CALL_REPORT_ROUTING_FAILURE	3	Any other value
 * 
 */
public final class CallReleaseCause implements java.io.Serializable {

    private int value;
    private int location;

    /**
     * Creates a new CallReleaseCause instance.
     */
    public CallReleaseCause () {}

    /**
     * Creates a new CallReleaseCause instance.
     * @param _value   
     * @param _location   
     */
    public CallReleaseCause (int _value, int _location) {

        this.value = _value;
        this.location = _location;
    }

    /**
     * This method returns a value.
     * 
     * @return a int value
     */
    public int getValue() {
        return value;
    }

    /**
     * This method returns a location.
     * 
     * @return a int value
     */
    public int getLocation() {
        return location;
    }


    /**
     * This method sets a value.
     */ 
    public void setValue(int value) {
        this.value = value;
    }

    /**
     * This method sets a location.
     */ 
    public void setLocation(int location) {
        this.location = location;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof CallReleaseCause)) {
            return false;
        } 
        CallReleaseCause callReleaseCause = (CallReleaseCause) o;
        if(!(this.value == callReleaseCause.value)) {
            return false;
        }
        if(!(this.location == callReleaseCause.location)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // CallReleaseCause

